@@ -6,7 +6,7 @@
 import json
 import numbers
 from binascii import a2b_base64
-from datetime import datetime
+from datetime import date, datetime
 
 import pytest
 from jupyter_client._version import version_info as jupyter_client_version
@@ -14,7 +14,7 @@ from jupyter_client._version import version_info as jupyter_client_version
 from .. import jsonutil
 from ..jsonutil import encode_images, json_clean
 
-JUPYTER_CLIENT_MAJOR_VERSION = jupyter_client_version[0]
+JUPYTER_CLIENT_MAJOR_VERSION: int = jupyter_client_version[0]  # type:ignore
 
 
 class MyInt:
@@ -53,14 +53,15 @@ def test():
         # More exotic objects
         ((x for x in range(3)), [0, 1, 2]),
         (iter([1, 2]), [1, 2]),
-        (datetime(1991, 7, 3, 12, 00), "1991-07-03T12:00:00.000000"),
+        (datetime(1991, 7, 3, 12, 00), "1991-07-03T12:00:00.000000"),  # noqa
+        (date(1991, 7, 3), "1991-07-03T00:00:00.000000"),
         (MyFloat(), 3.14),
         (MyInt(), 389),
     ]
 
     for val, jval in pairs:
         if jval is None:
-            jval = val
+            jval = val  # type:ignore
         out = json_clean(val)
         # validate our cleanup
         assert out == jval
